===================
``spelling`` module
===================

See :doc:`how to use the Whoosh spell checker <../spelling>`.

.. automodule:: whoosh.spelling

.. autoclass:: SpellChecker
    :inherited-members:
    :members:
